
### Introduction
Watch a quick introduction to Laktory, the open-source ETL framework, and learn how you can leverage its pipeline model 
to efficiently build and deploy dataframe-centric pipelines to Databricks or other data platforms.

![type:video](https://www.youtube.com/embed/BZK0PE-OriQ)

### Overview
Watch a hands-on demo on how to use Laktory to build a scalable data pipeline. It covers:

- Declare a data pipeline backed by Polars dataframes and run it locally
- Change backend to Spark dataframe and run it on a Databricks cluster
- Deploy as a databricks job and as a Delta Live Tables using Laktory CLI

![type:video](https://www.youtube.com/embed/010w2iWrN0w)

### Requests
You may request a live demo from Okube [website](https://www.okube.ai/contact).